============
Installation
============

At the command line either via easy_install or pip::

    $ easy_install gryaml
    $ pip install gryaml

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv gryaml
    $ pip install gryaml
